#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const tslib_1 = require("tslib");
const fs_1 = require("./fs");
const path_1 = require("path");
const logger_1 = require("./logger");
const default_cli_1 = require("./default-cli");
const child_process_1 = require("child_process");
const { foyFiles, registers } = (0, default_cli_1.initDefaultCli)();
function main() {
    return tslib_1.__awaiter(this, void 0, void 0, function* () {
        const pkg = yield fs_1.fs.readJson('./package.json');
        const isESM = pkg.type === 'module';
        const deps = Object.assign(Object.assign({}, pkg.dependencies), pkg.devDependencies);
        for (const foyFile of foyFiles) {
            let env = 'node';
            if (['.ts', '.cts', '.tsx', '.ctsx'].includes((0, path_1.extname)(foyFile))) {
                if ('ts-node' in deps) {
                    env = 'ts-node';
                }
                else if ('tsx' in deps) {
                    env = 'tsx';
                }
                else if ('@swc-node/register' in deps) {
                    if (isESM) {
                        registers.push('@swc-node/register/esm-register');
                    }
                    else {
                        registers.push('@swc-node/register');
                    }
                }
                else if ('swc-node' in deps) {
                    env = 'swc-node';
                }
                else {
                    logger_1.logger.error('no ts-node/tsx/swc-node or @swc-node/register found');
                    process.exit(1);
                }
            }
            const args = [
                ...registers.map((r) => `--${isESM ? 'import' : 'require'} ${r}`),
                foyFile,
                ...process.argv.slice(2),
            ];
            (0, child_process_1.spawn)(env, args, {
                stdio: 'inherit'
            });
        }
    });
}
main().catch((err) => {
    console.error(err);
});
//# sourceMappingURL=cli.js.map