"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.DepBuilder = void 0;
exports.dep = dep;
const utils_1 = require("./utils");
class DepBuilder {
    constructor(name) {
        this._isDepBuilder = true;
        if (utils_1.Is.str(name)) {
            name = { name };
        }
        else if (name instanceof DepBuilder) {
            name = name.toTaskDep();
        }
        this._dep = name;
    }
    /**
     *
     * Dependences are executed serially by default.
     * If order doesn't matter and you want better performance via parallel, you can mark it as asynchronized.
     * Asynchronized will run immediately whether there are synchronized tasks before them or not.
     * You can pass a number as the priority of asynchronized tasks, bigger is formmer.
     * @param priority
     */
    async(priority = true) {
        this._dep.async = priority;
        return this;
    }
    force() {
        this._dep.force = true;
        return this;
    }
    options(opts) {
        if (utils_1.Is.fn(opts)) {
            this._dep.resolveOptions = opts;
        }
        else {
            this._dep.options = opts;
        }
        return this;
    }
    toTaskDep() {
        return this._dep;
    }
}
exports.DepBuilder = DepBuilder;
function dep(dep) {
    if (utils_1.Is.str(dep)) {
        dep = { name: dep };
    }
    return new DepBuilder(dep);
}
String.prototype.async = function (priority) {
    return dep(this).async(priority);
};
String.prototype.force = function () {
    return dep(this).force();
};
String.prototype.options = function (opts) {
    return dep(this).options(opts);
};
//# sourceMappingURL=dep-builder.js.map