#!/usr/bin/env node
"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.runCli = runCli;
exports.deferRunCli = deferRunCli;
const tslib_1 = require("tslib");
const cac_1 = tslib_1.__importDefault(require("cac"));
const logger_1 = require("./logger");
const task_manager_1 = require("./task-manager");
const default_cli_1 = require("./default-cli");
function runCli() {
    const { defaultCli, defaultHelpMsg, outputCompletion, taskArgv } = (0, default_cli_1.initDefaultCli)();
    const taskCli = (0, cac_1.default)("foy");
    let taskManager = (0, task_manager_1.getGlobalTaskManager)();
    taskManager.getTasks().forEach((t) => {
        let strict = taskManager.globalOptions.strict || t.strict;
        let cmd = taskCli.command(t.name, t.desc, { allowUnknownOptions: !strict });
        if (t.optionDefs) {
            t.optionDefs.forEach((def) => cmd.option(...def));
        }
        cmd.action((...args) => tslib_1.__awaiter(this, void 0, void 0, function* () {
            let options = args.pop();
            let { globalOptions } = taskManager;
            globalOptions.rawArgs = taskCli.rawArgs;
            globalOptions.options = options;
            yield taskManager
                .run(t.name, {
                options,
                rawArgs: taskCli.rawArgs.slice(3),
            })
                .catch((err) => {
                logger_1.logger.error(err);
                throw err;
            });
        }));
    });
    taskCli.help((sections) => {
        if (!taskCli.matchedCommand) {
            let last = sections[sections.length - 1];
            let lines = last.body.split('\n');
            lines.pop();
            last.body = defaultHelpMsg;
        }
        console.log(sections
            .map((section) => {
            return section.title ? `${section.title}:\n${section.body}` : section.body;
        })
            .join('\n\n'));
        process.exit(0);
    });
    outputCompletion(taskCli);
    taskCli.on('command:*', () => {
        console.error(`error: Unknown command \`${taskCli.args.join(' ')}\`\n\n`);
        process.exit(1);
    });
    taskCli.parse(taskArgv);
    if (process.argv.length === 2) {
        taskCli.outputHelp();
    }
}
let timer;
function deferRunCli() {
    if (timer)
        return;
    timer && clearTimeout(timer);
    timer = setTimeout(runCli);
}
//# sourceMappingURL=run-cli.js.map