"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.formatDate = exports.DefaultLogFile = exports.Is = exports.sleep = void 0;
exports.getType = getType;
exports.hashAny = hashAny;
exports.debounce = debounce;
exports.promiseQueue = promiseQueue;
exports.defaults = defaults;
exports.formatDuration = formatDuration;
const path_1 = require("path");
let objUid = 0;
let objUidMap = new WeakMap();
/** @internal */
function getType(key) {
    const t = Object.prototype.toString.call(key);
    return t.slice(8, -1).toLowerCase();
}
/** @internal */
function hashAny(key) {
    switch (getType(key)) {
        case 'undefined':
        case 'null':
        case 'boolean':
        case 'number':
        case 'regexp':
            return key + '';
        case 'date':
            return '📅' + key.getTime();
        case 'string':
            return '📝' + key;
        case 'array':
            return '🔗' + key.map((k) => hashAny(k)).join('⁞');
        case 'object':
            return (key.constructor.name +
                JSON.stringify(key, (k, v) => {
                    if (!k)
                        return v;
                    return hashAny(v);
                }));
        default:
            let uid = objUidMap.get(key);
            if (!uid) {
                uid = ++objUid;
                objUidMap.set(key, uid);
            }
            return '⭕️' + uid;
    }
}
const sleep = (ms) => {
    return new Promise((res) => setTimeout(res, ms));
};
exports.sleep = sleep;
function debounce(cb, ms, getArgsKey = (args) => args.join('|')) {
    let timerMap = new Map();
    let newCb = (...args) => {
        if (timerMap.size > 20) {
            timerMap = new Map();
        }
        const key = getArgsKey(args);
        let timer = timerMap.get(key);
        timer && clearTimeout(timer);
        timer = setTimeout(cb, ms, ...args);
        timerMap.set(key, timer);
    };
    return newCb;
}
function promiseQueue(cb) {
    let promiseQueue = Promise.resolve(null);
    return (...args) => {
        promiseQueue = promiseQueue.then(() => cb(...args));
        return promiseQueue;
    };
}
exports.Is = {
    defined(v) {
        return typeof v !== 'undefined' && v !== null;
    },
    str(v) {
        return typeof v === 'string';
    },
    bool(v) {
        return typeof v === 'boolean';
    },
    fn(v) {
        return typeof v === 'function';
    },
    obj(v) {
        return v && typeof v === 'object';
    },
    num(v) {
        return typeof v === 'number';
    },
};
function defaults(...args) {
    let [val, ...defaultVals] = args;
    if (exports.Is.defined(val))
        return val;
    if (defaultVals.length === 0) {
        return val;
    }
    return defaults(...defaultVals);
}
exports.DefaultLogFile = (0, path_1.join)(process.cwd(), 'foy.log');
const formatDate = (d) => `${d.getFullYear()}-${d.getMonth() + 1}-${d.getDate()} ${d.getHours()}:${d.getMinutes()}:${d.getSeconds()}`;
exports.formatDate = formatDate;
function formatDuration(ms) {
    return Number((ms / 1000).toFixed(2)) + 's';
}
//# sourceMappingURL=utils.js.map